
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 100
#define YY_END_OF_BUFFER 101
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[237] =
    {   0,
        0,    0,    0,    0,  101,  100,   99,   50,  100,   61,
        9,   43,   63,   66,   56,   14,   46,   21,   19,   86,
       86,   13,   64,   42,   25,   33,   57,   98,   38,   59,
       79,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,   98,   37,   53,   58,   71,    2,    4,    3,
       49,    0,   67,    0,   60,    7,    8,   65,   55,   54,
       44,   45,   94,    6,    5,   18,   94,   86,    0,    0,
       90,   87,    0,   90,   86,   40,   41,   24,   31,   32,
       98,   98,   78,   98,   98,   98,   98,   20,   98,   98,
       98,   98,   98,   34,   35,   98,   98,   98,   98,   98,

       98,   98,   98,   98,   98,   98,   51,   52,    2,    1,
       48,    0,   94,    5,    0,   95,   92,   89,   88,   88,
        0,   86,   39,   23,   30,    0,   98,   98,   98,   98,
       98,   98,   98,   98,   98,   98,   27,   98,   98,   47,
       98,   98,   98,   98,   98,   98,   98,   72,   98,   74,
       98,   98,   98,    0,   94,   95,   93,   91,    0,    0,
        0,   29,   98,   11,   98,   98,   98,   98,   98,   98,
       22,   98,   98,   98,   98,   80,   98,   98,   98,   69,
       98,   81,   98,   75,   98,   77,    0,    0,   97,   10,
       12,   83,   98,   98,   98,   98,   82,   98,   98,   98,

       98,   98,   98,   70,   98,   76,    0,   96,   97,   98,
       98,   98,   17,   98,   98,   98,   98,   62,   68,   73,
       96,   98,   98,   16,   26,   98,   98,   98,   15,   84,
       28,   98,   85,   98,   36,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    6,    7,    1,    8,
        9,   10,   11,   12,   13,   14,   15,   16,   17,   17,
       17,   17,   17,   17,   17,   18,   18,   19,   20,   21,
       22,   23,   24,    1,   25,   25,   25,   25,   26,   27,
       28,   28,   28,   28,   28,   29,   28,   28,   28,   30,
       28,   28,   28,   28,   31,   28,   28,   32,   28,   28,
       33,   34,   35,   36,   37,    1,   38,   39,   40,   41,

       42,   43,   44,   45,   46,   28,   47,   48,   28,   49,
       50,   51,   28,   52,   53,   54,   55,   56,   57,   32,
       58,   28,   59,   60,   61,   62,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[63] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    3,
        1,    1,    1,    4,    1,    5,    5,    5,    1,    1,
        1,    1,    1,    1,    5,    5,    5,    6,    6,    6,
        6,    6,    1,    1,    1,    1,    6,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    1,    1,
        1,    1
    } ;

static yyconst flex_int16_t yy_base[245] =
    {   0,
        0,    0,   60,   61,  212,  879,  879,  187,   60,  181,
       59,  879,  879,  171,   56,  879,   55,   56,   65,   81,
       68,  879,  879,   61,  158,   66,  879,   74,  879,  879,
      156,   85,   88,   98,  101,  104,  114,  127,  135,  117,
      144,  118,  120,  879,   86,  879,  879,    0,  879,  161,
      149,   91,  879,  164,  879,  879,  879,  879,  879,  879,
      879,  879,  168,  879,    0,  879,  188,  115,  206,  222,
      152,   80,  127,  124,    0,  117,  879,  105,  879,  165,
        0,  174,  879,  183,  210,  225,  228,  233,  236,  239,
      242,  252,  261,  264,  267,  276,  279,  282,  285,  291,

      295,  298,  305,  301,  308,  312,  879,  879,    0,  879,
      879,  328,  879,    0,  342,  345,   38,  879,   95,   63,
        0,  350,  879,  879,  879,   57,  351,  360,  366,  369,
      374,  378,  391,  394,  397,  401,  408,  414,  424,  427,
      431,  435,  439,  442,  445,  449,  453,  456,  464,  467,
      470,  473,  484,  487,  491,  879,  879,  879,  168,  178,
      499,  879,  506,  509,  514,  519,  524,  527,  530,  533,
      538,  544,  547,  550,  558,  561,  564,  572,  575,  581,
      584,  589,  592,  595,  601,  604,  612,  615,  618,  621,
      632,  635,  638,  641,  646,  651,  654,  657,  660,  663,

      666,  672,  679,  682,  685,  691,  697,  700,  879,  714,
      717,  720,  723,  728,  733,  736,  739,  744,  747,  750,
      879,  754,  761,  771,  774,  777,  781,  784,  787,  790,
      793,  798,  801,  804,  811,  879,  848,  854,  856,  862,
      868,  871,  872,   71
    } ;

static yyconst flex_int16_t yy_def[245] =
    {   0,
      236,    1,  237,  237,  236,  236,  236,  236,  238,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
       20,  236,  236,  236,  236,  236,  236,  239,  236,  236,
      236,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,   36,   36,  236,  236,  236,  236,  240,  236,  236,
      236,  238,  236,  238,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  241,  236,  236,   20,  236,  236,
      236,  236,  242,  236,   21,  236,  236,  236,  236,  236,
      243,  239,  236,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,

      239,  239,  239,  239,  239,  239,  236,  236,  240,  236,
      236,  236,  236,  241,  236,  236,  236,  236,  236,  236,
      244,  242,  236,  236,  236,  236,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  236,  236,  236,  236,  236,  244,  244,
      236,  236,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,  239,  236,  236,  236,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,

      239,  239,  239,  239,  239,  239,  236,  236,  236,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      236,  239,  239,  239,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  239,    0,  236,  236,  236,  236,
      236,  236,  236,  236
    } ;

static yyconst flex_int16_t yy_nxt[942] =
    {   0,
        6,    7,    7,    8,    9,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   20,   21,   21,   22,   23,
       24,   25,   26,   27,   28,   28,   28,   28,   28,   28,
       28,   28,   29,    6,   30,   31,   28,   28,   32,   33,
       34,   35,   36,   28,   28,   37,   28,   28,   38,   28,
       28,   39,   40,   41,   28,   42,   43,   28,   44,   45,
       46,   47,   49,   49,   53,   56,   59,   61,  157,   50,
       50,   63,   63,   63,   64,  159,   62,   60,  162,   65,
       57,   76,   77,   75,   75,   75,   66,   79,   80,   81,
       81,   81,  157,   54,   67,   53,   68,   68,   69,  236,

       81,   81,   81,   81,   81,   81,   70,  107,  119,   71,
      158,   72,   73,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   70,  158,   54,   85,  124,  120,   74,   81,
       81,   81,   81,   81,   81,   72,   84,   86,  123,   87,
      121,   90,   81,   81,   81,  108,  236,   88,   89,   91,
       81,   81,   81,   92,  118,  103,   94,   82,   93,   81,
       81,   81,   95,   82,  105,  106,  236,  104,   96,   82,
      111,  117,   82,   99,   82,  110,   98,   83,  118,   78,
      117,   97,  118,   63,   63,   63,  125,  126,  100,   81,
       81,   81,   58,  112,  113,  101,  113,  187,   81,   81,

       81,  102,   55,   63,   63,   63,  118,  187,   51,  112,
      113,  236,  236,  112,  113,  113,  113,  236,  187,   67,
      236,   69,   69,   69,  127,   81,   81,   81,  187,  112,
      113,   70,  115,  236,  115,  113,  236,  116,  116,  116,
       81,   81,   81,   81,   81,   81,  236,   70,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
      236,  236,  128,  129,  236,  236,  131,   81,   81,   81,
      132,  236,  236,  130,  236,  133,   81,   81,   81,   81,
       81,   81,   81,   81,   81,  236,  135,  236,  134,  236,
      136,   81,   81,   81,   81,   81,   81,   81,   81,   81,

       81,   81,   81,  137,  236,  236,   81,   81,   81,  138,
       81,   81,   81,   81,   81,   81,   81,   81,   81,  139,
       81,   81,   81,   81,   81,   81,  141,   81,   81,   81,
      144,  236,  140,  236,  142,  143,  145,  236,  154,  236,
      154,  236,  146,  155,  155,  155,  151,  236,  149,  147,
      236,  236,  148,  152,  236,  236,  150,  116,  116,  116,
      116,  116,  116,  160,  236,  153,   81,   81,   81,  236,
      236,  156,  236,  156,  236,   81,   81,   81,   71,  161,
       72,   81,   81,   81,   81,   81,   81,  156,  163,   81,
       81,   81,  156,   81,   81,   81,  236,   74,  236,  236,

      161,  164,  236,  236,   72,  165,   81,   81,   81,   81,
       81,   81,   81,   81,   81,  169,   81,   81,   81,  236,
      236,  166,  167,   81,   81,   81,  236,  236,  168,   81,
       81,   81,  170,  236,  236,  171,  236,  236,  173,   81,
       81,   81,   81,   81,   81,  236,   81,   81,   81,  172,
       81,   81,   81,  174,   81,   81,   81,   81,   81,   81,
       81,   81,   81,  236,   81,   81,   81,  236,   81,   81,
       81,   81,   81,   81,  236,  236,  177,  175,  176,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,  236,  236,  178,  182,  179,  236,  180,  181,   81,

       81,   81,  155,  155,  155,  183,  155,  155,  155,  188,
      184,  188,  236,  236,  189,  189,  189,  113,  236,  113,
      185,   81,   81,   81,   81,   81,   81,  236,  186,   81,
       81,   81,  236,  113,   81,   81,   81,  236,  113,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,  236,  190,   81,   81,   81,  236,  236,  191,   81,
       81,   81,   81,   81,   81,   81,   81,   81,  236,  193,
      194,  236,  192,   81,   81,   81,   81,   81,   81,   81,
       81,   81,  236,  236,  195,  197,  196,   81,   81,   81,
       81,   81,   81,  236,  198,  200,   81,   81,   81,   81,

       81,   81,  236,  199,   81,   81,   81,   81,   81,   81,
       81,   81,   81,  236,  203,  201,   81,   81,   81,   81,
       81,   81,  207,  202,  207,  236,  236,  208,  208,  208,
      189,  189,  189,  189,  189,  189,   81,   81,   81,  236,
      204,  205,  206,  236,  209,  236,  209,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,  236,
      209,   81,   81,   81,  236,  209,   81,   81,   81,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,   81,   81,   81,  211,  236,  210,   81,   81,   81,
      236,  236,  213,  212,   81,   81,   81,   81,   81,   81,

       81,   81,   81,  236,  214,  215,   81,   81,   81,  236,
      236,  216,  208,  208,  208,  208,  208,  208,  236,  236,
      218,  217,  236,  219,  236,  236,  221,  220,  221,   81,
       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,  236,  221,   81,   81,   81,  236,  221,   81,   81,
       81,   81,   81,   81,   81,   81,   81,  236,  223,   81,
       81,   81,   81,   81,   81,   81,   81,   81,  222,   81,
       81,   81,  236,  224,  236,  227,   81,   81,   81,  236,
      228,  236,  226,  236,  236,  225,   81,   81,   81,   81,
       81,   81,   81,   81,   81,  229,   81,   81,   81,   81,

       81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
       81,  236,  230,   81,   81,   81,   81,   81,   81,   81,
       81,   81,  232,  236,  233,  231,   81,   81,   81,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  235,  234,   48,   48,
       48,   48,   48,   48,   52,   52,   52,   52,   52,   52,
       82,   82,  109,  236,  236,  109,  109,  109,  114,  236,
      114,  114,  114,  114,  122,  122,   81,   81,    5,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,

      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236
    } ;

static yyconst flex_int16_t yy_chk[942] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,    9,   11,   15,   17,  117,    3,
        4,   18,   18,   18,   19,  244,   17,   15,  126,   19,
       11,   24,   24,   21,   21,   21,   19,   26,   26,   28,
       28,   28,  117,    9,   20,   52,   20,   20,   20,   21,

       32,   32,   32,   33,   33,   33,   20,   45,   72,   20,
      120,   20,   20,   34,   34,   34,   35,   35,   35,   36,
       36,   36,   20,  119,   52,   33,   78,   72,   20,   37,
       37,   37,   40,   40,   40,   20,   32,   33,   76,   34,
       73,   36,   38,   38,   38,   45,   68,   34,   35,   36,
       39,   39,   39,   36,   74,   42,   37,   43,   36,   41,
       41,   41,   37,   42,   43,   43,   54,   42,   38,   43,
       51,   74,   42,   40,   43,   50,   39,   31,   74,   25,
       71,   38,   71,   63,   63,   63,   80,   80,   41,   82,
       82,   82,   14,   63,   63,   41,   63,  159,   84,   84,

       84,   41,   10,   67,   67,   67,   71,  160,    8,   63,
       63,    5,    0,   67,   67,   63,   67,    0,  159,   69,
        0,   69,   69,   69,   84,   85,   85,   85,  160,   67,
       67,   69,   70,    0,   70,   67,    0,   70,   70,   70,
       86,   86,   86,   87,   87,   87,    0,   69,   88,   88,
       88,   89,   89,   89,   90,   90,   90,   91,   91,   91,
        0,    0,   85,   85,    0,    0,   87,   92,   92,   92,
       87,    0,    0,   86,    0,   87,   93,   93,   93,   94,
       94,   94,   95,   95,   95,    0,   90,    0,   89,    0,
       91,   96,   96,   96,   97,   97,   97,   98,   98,   98,

       99,   99,   99,   92,    0,    0,  100,  100,  100,   93,
      101,  101,  101,  102,  102,  102,  104,  104,  104,   95,
      103,  103,  103,  105,  105,  105,   97,  106,  106,  106,
       99,    0,   96,    0,   98,   98,  100,    0,  112,    0,
      112,    0,  100,  112,  112,  112,  104,    0,  102,  101,
        0,    0,  101,  105,    0,    0,  103,  115,  115,  115,
      116,  116,  116,  122,    0,  106,  127,  127,  127,    0,
        0,  116,    0,  116,    0,  128,  128,  128,  122,  122,
      122,  129,  129,  129,  130,  130,  130,  116,  127,  131,
      131,  131,  116,  132,  132,  132,    0,  122,    0,    0,

      122,  128,    0,    0,  122,  129,  133,  133,  133,  134,
      134,  134,  135,  135,  135,  132,  136,  136,  136,    0,
        0,  130,  130,  137,  137,  137,    0,    0,  131,  138,
      138,  138,  133,    0,    0,  134,    0,    0,  136,  139,
      139,  139,  140,  140,  140,    0,  141,  141,  141,  135,
      142,  142,  142,  138,  143,  143,  143,  144,  144,  144,
      145,  145,  145,    0,  146,  146,  146,    0,  147,  147,
      147,  148,  148,  148,    0,    0,  142,  139,  141,  149,
      149,  149,  150,  150,  150,  151,  151,  151,  152,  152,
      152,    0,    0,  143,  147,  144,    0,  145,  146,  153,

      153,  153,  154,  154,  154,  149,  155,  155,  155,  161,
      151,  161,    0,    0,  161,  161,  161,  155,    0,  155,
      152,  163,  163,  163,  164,  164,  164,    0,  153,  165,
      165,  165,    0,  155,  166,  166,  166,    0,  155,  167,
      167,  167,  168,  168,  168,  169,  169,  169,  170,  170,
      170,    0,  163,  171,  171,  171,    0,    0,  165,  172,
      172,  172,  173,  173,  173,  174,  174,  174,    0,  167,
      168,    0,  166,  175,  175,  175,  176,  176,  176,  177,
      177,  177,    0,    0,  169,  172,  170,  178,  178,  178,
      179,  179,  179,    0,  173,  175,  180,  180,  180,  181,

      181,  181,    0,  174,  182,  182,  182,  183,  183,  183,
      184,  184,  184,    0,  179,  177,  185,  185,  185,  186,
      186,  186,  187,  178,  187,    0,    0,  187,  187,  187,
      188,  188,  188,  189,  189,  189,  190,  190,  190,    0,
      181,  183,  185,    0,  189,    0,  189,  191,  191,  191,
      192,  192,  192,  193,  193,  193,  194,  194,  194,    0,
      189,  195,  195,  195,    0,  189,  196,  196,  196,  197,
      197,  197,  198,  198,  198,  199,  199,  199,  200,  200,
      200,  201,  201,  201,  194,    0,  193,  202,  202,  202,
        0,    0,  196,  195,  203,  203,  203,  204,  204,  204,

      205,  205,  205,    0,  198,  199,  206,  206,  206,    0,
        0,  200,  207,  207,  207,  208,  208,  208,    0,    0,
      202,  201,    0,  203,    0,    0,  208,  205,  208,  210,
      210,  210,  211,  211,  211,  212,  212,  212,  213,  213,
      213,    0,  208,  214,  214,  214,    0,  208,  215,  215,
      215,  216,  216,  216,  217,  217,  217,    0,  211,  218,
      218,  218,  219,  219,  219,  220,  220,  220,  210,  222,
      222,  222,    0,  212,    0,  216,  223,  223,  223,    0,
      217,    0,  215,    0,    0,  214,  224,  224,  224,  225,
      225,  225,  226,  226,  226,  222,  227,  227,  227,  228,

      228,  228,  229,  229,  229,  230,  230,  230,  231,  231,
      231,    0,  223,  232,  232,  232,  233,  233,  233,  234,
      234,  234,  227,    0,  228,  226,  235,  235,  235,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  234,  232,  237,  237,
      237,  237,  237,  237,  238,  238,  238,  238,  238,  238,
      239,  239,  240,    0,    0,  240,  240,  240,  241,    0,
      241,  241,  241,  241,  242,  242,  243,  243,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,

      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "js_lex.l"
#define YY_NO_UNISTD_H 1

#line 7 "js_lex.l"
#include "js_parser.tab.hh"
#include <cstdlib>
#include <cstdio>
#include <QtCore>
#include <io.h>


#define YY_DECL int yylex(yy::JSCacheParser::semantic_type* yylval,yy::JSCacheParser::location_type* yylloc)
#define YY_USER_ACTION yylloc->columns(yyleng);

typedef yy::JSCacheParser::token token;
#line 755 "lex.yy.c"

#define INITIAL 0
#define MLCOMMENTSTATE 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 34 "js_lex.l"



	yylloc->step();

				
#line 945 "lex.yy.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 237 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 879 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 40 "js_lex.l"
{BEGIN(INITIAL);}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 41 "js_lex.l"
{}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 42 "js_lex.l"
{}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 43 "js_lex.l"
{}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 44 "js_lex.l"
{}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 45 "js_lex.l"
{BEGIN(MLCOMMENTSTATE);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 46 "js_lex.l"
{}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 47 "js_lex.l"
{}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 48 "js_lex.l"
{}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 49 "js_lex.l"
{}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 50 "js_lex.l"
{}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 51 "js_lex.l"
{}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 52 "js_lex.l"
{return token::T_COLON;}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 53 "js_lex.l"
{return token::T_COMMA;}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 54 "js_lex.l"
{}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 55 "js_lex.l"
{}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 56 "js_lex.l"
{}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 57 "js_lex.l"
{}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 58 "js_lex.l"
{}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 59 "js_lex.l"
{}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 60 "js_lex.l"
{return token::T_DOT;}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 61 "js_lex.l"
{}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 62 "js_lex.l"
{}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 63 "js_lex.l"
{}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 64 "js_lex.l"
{return token::T_EQ;}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 65 "js_lex.l"
{}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 66 "js_lex.l"
{}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 67 "js_lex.l"
{return token::T_FUNCTION;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 68 "js_lex.l"
{}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 69 "js_lex.l"
{}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 70 "js_lex.l"
{}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 71 "js_lex.l"
{}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 72 "js_lex.l"
{}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 73 "js_lex.l"
{}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 74 "js_lex.l"
{}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 75 "js_lex.l"
{}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 76 "js_lex.l"
{return token::T_LBRACKET;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 77 "js_lex.l"
{return token::T_LBRACE;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 78 "js_lex.l"
{}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 79 "js_lex.l"
{}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 80 "js_lex.l"
{}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 81 "js_lex.l"
{}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 82 "js_lex.l"
{return token::T_LPAREN;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 83 "js_lex.l"
{}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 84 "js_lex.l"
{}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 85 "js_lex.l"
{}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 86 "js_lex.l"
{return token::T_NEW;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 87 "js_lex.l"
{}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 88 "js_lex.l"
{} 
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 89 "js_lex.l"
{}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 90 "js_lex.l"
{}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 91 "js_lex.l"
{}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 92 "js_lex.l"
{}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 93 "js_lex.l"
{}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 94 "js_lex.l"
{}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 95 "js_lex.l"
{}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 96 "js_lex.l"
{}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 97 "js_lex.l"
{return token::T_RBRACKET;}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 98 "js_lex.l"
{return token::T_RBRACE;}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 99 "js_lex.l"
{}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 100 "js_lex.l"
{}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 101 "js_lex.l"
{}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 102 "js_lex.l"
{return token::T_RPAREN;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 103 "js_lex.l"
{return token::T_SEMICOLON;}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 104 "js_lex.l"
{}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 105 "js_lex.l"
{}
	YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
#line 106 "js_lex.l"
{return token::T_STRING_LITERAL;}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 107 "js_lex.l"
{}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 108 "js_lex.l"
{return token::T_THIS;}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 109 "js_lex.l"
{}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 110 "js_lex.l"
{}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 111 "js_lex.l"
{}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 112 "js_lex.l"
{}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 113 "js_lex.l"
{return token::T_VAR;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 114 "js_lex.l"
{}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 115 "js_lex.l"
{}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 116 "js_lex.l"
{}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 117 "js_lex.l"
{}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 118 "js_lex.l"
{}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 119 "js_lex.l"
{return token::T_NULL;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 120 "js_lex.l"
{}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 121 "js_lex.l"
{}	
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 122 "js_lex.l"
{return token::T_CONST;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 123 "js_lex.l"
{}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 124 "js_lex.l"
{}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 125 "js_lex.l"
{yylval->i = QString(yytext).toInt();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 126 "js_lex.l"
{yylval->u = QString(yytext).toUInt();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 127 "js_lex.l"
{yylval->ul = QString(yytext).toULong();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 128 "js_lex.l"
{yylval->ul = QString(yytext).toULong();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 129 "js_lex.l"
{yylval->l = QString(yytext).toLong();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 130 "js_lex.l"
{yylval->l = QString(yytext).toULongLong();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 131 "js_lex.l"
{yylval->l = QString(yytext).toLongLong();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 132 "js_lex.l"
{yylval->l = QString(yytext).toULongLong();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 133 "js_lex.l"
{yylval->f = QString(yytext).toFloat();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 134 "js_lex.l"
{yylval->f = QString(yytext).toFloat();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 135 "js_lex.l"
{yylval->f = QString(yytext).toFloat();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 136 "js_lex.l"
{yylval->f = QString(yytext).toFloat();return token::T_NUMERIC_LITERAL;}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 137 "js_lex.l"
{yylval->s = new QString(yytext);return token::T_IDENTIFIER;}
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 138 "js_lex.l"
{}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 140 "js_lex.l"
ECHO;
	YY_BREAK
#line 1531 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(MLCOMMENTSTATE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 237 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 237 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 236);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 140 "js_lex.l"



